@@ -54,7 +54,8 @@ def vis_tsne2d(df: pd.DataFrame, target_col: str, true_label_col: str, show_off:
         legend="full"
         )
     if save_plot_path is not None:
-        plt.savefig(save_plot_path, bbox_inches='tight')
+        plt.title('T-SNE 3D')
+        plt.savefig(save_plot_path, dpi=300, bbox_inches='tight')
     if show_off:
         plt.switch_backend("Agg")
     
@@ -107,7 +108,7 @@ def vis_tsne3d(df: pd.DataFrame, target_col: str, true_label_col: str, show_off:
     ax.legend()
 
     if save_plot_path is not None:
-        plt.savefig(save_plot_path, bbox_inches='tight')
+        plt.savefig(save_plot_path, dpi=300, bbox_inches='tight')
     if show_off:
         plt.switch_backend("Agg")
 
@@ -154,18 +155,22 @@ def vis_pca(df: pd.DataFrame, target_col: str, true_label_col: str, pca_dim: int
     print('Explained variation per PC(Principal Component): {}'.format(pca.explained_variance_ratio_))
     
     if pca_dim == 2:
-        sns.scatterplot(
-            x="PC1", y="PC2",
-            hue=true_label_col,
-            palette=sns.color_palette("Set2", len(df[true_label_col].unique())),
-            data=df,
-            legend="full"
-            )
-        plt.title('PCA 2DIM')
-        if save_plot_path is not None:
-            plt.savefig(save_plot_path, dpi=300, bbox_inches='tight')
+        if true_label_col is None:
+            ax.scatter(df['PC1'], df['pa-2']) 
+        else:
+            sns.scatterplot(
+                x="PC1", y="PC2",
+                hue=true_label_col,
+                palette=sns.color_palette("Set2", len(df[true_label_col].unique())),
+                data=df,
+                legend="full"
+                )
+            plt.title('PCA 2D')
+            if save_plot_path is not None:
+                plt.savefig(save_plot_path, dpi=300, bbox_inches='tight')
+                
     elif pca_dim == 3:
-        ax = plt.figure(figsize=(10,10)).gca(projection='3d')
+        ax = plt.axes(projection='3d')
         if true_label_col is None:
             ax.scatter(df['PC1'], df['pa-2'], df['PC3']) 
         else:
@@ -179,6 +184,7 @@ def vis_pca(df: pd.DataFrame, target_col: str, true_label_col: str, pca_dim: int
         ax.set_ylabel('PC2')
         ax.set_zlabel('PC3')
         if save_plot_path is not None:
+            plt.title('PCA 3D')
             plt.savefig(save_plot_path, dpi=300, bbox_inches='tight')
     if show_off:
         plt.switch_backend("Agg")
